package com.gqy.web.controller.document;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.gqy.common.core.controller.BaseController;
import com.gqy.common.core.domain.AjaxResult;
import com.gqy.common.core.domain.AjaxResultCQY;
import com.gqy.common.utils.StringUtils;
import com.gqy.document.domain.DcTemplate;
import com.gqy.document.domain.vo.PageResult;
import com.gqy.document.service.IDcTemplateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/template")
public class DcTemplateController extends BaseController {

    @Autowired
    private IDcTemplateService templateService;

    /**
     * 搜索模板列表
     * 对应Python的@require_http_methods(['POST'])
     */
    @PostMapping("/search")
    @ResponseBody
    public AjaxResultCQY search(HttpServletRequest request) {
        // 获取表单参数
        String name = request.getParameter("name");
        String category_id = request.getParameter("category_id");
        String status = request.getParameter("status");
        String page = request.getParameter("page");
        String page_size = request.getParameter("pageSize");

        // 参数转换
        Integer categoryId = StringUtils.isNotEmpty(category_id) ? Integer.valueOf(category_id) : null;
        Integer statusInt = StringUtils.isNotEmpty(status) ? Integer.valueOf(status) : null;
        Integer pageNum = StringUtils.isNotEmpty(page) ? Integer.valueOf(page) : 1;
        Integer pageSize = StringUtils.isNotEmpty(page_size) ? Integer.valueOf(page_size) : 10;

        // 分页查询
        PageHelper.startPage(pageNum, pageSize);

        List<DcTemplate> list = templateService.selectTemplateList(name, categoryId, statusInt);

        // 3. 获取分页信息
        PageInfo<DcTemplate> pageInfo = new PageInfo<>(list);

        // 4. 封装并返回结果
        PageResult PageResult=  new PageResult(
                pageInfo.getPageNum(),
                pageInfo.getPageSize(),
                pageInfo.getPages(),
                pageInfo.getTotal(),
                pageInfo.getList());

        return AjaxResultCQY.success("查询成功", PageResult);
    }

    /**
     * 获取模板详细信息
     *
     * @param id 模板ID
     * @return 模板详细信息，包括基本信息和分类信息
     */
    @PostMapping("/info")
    public AjaxResultCQY info(@RequestBody Map map) {
        Integer id = (Integer) map.get("id");
        return  templateService.getInfo(id.longValue());
    }



}
