package com.gqy.web.controller.document;

/**
 *
 */
import com.gqy.common.core.controller.BaseController;
import com.gqy.common.core.domain.AjaxResultCQY;
import com.gqy.document.domain.DocumentCategory;
import com.gqy.document.domain.vo.PageResult;
import com.gqy.document.service.IDocumentCategoryService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;


@RestController
@RequestMapping("/document")
public class DocumentCategoryController extends BaseController {

    private static final Logger log = LoggerFactory.getLogger(DocumentCategoryController.class);

    @Autowired
    private IDocumentCategoryService documentCategoryService;




    /**
     * 搜索文档分类列表
     *
     * @param request HTTP请求对象,包含以下参数:
     *        page: 页码(默认1)
     *        pageSize: 每页数量(默认10)
     *        name: 分类名称,支持模糊查询(可选)
     *        status: 状态(可选)
     * @return AjaxResult 返回结果:
     *         status: 状态码(200成功,500失败)
     *         message: 提示信息
     *         data: 分页数据对象
     */
    @PostMapping("/category/search")
    @ResponseBody
    public AjaxResultCQY search(HttpServletRequest request) {
        try {
            // 1. 获取分页参数(提供默认值)
            String page = request.getParameter("page");
            String pageSize = request.getParameter("pageSize");
            if (page == null) {
                page = "1";
            }
            if (pageSize == null) {
                pageSize = "10";
            }

            // 2. 获取查询条件
            String name = request.getParameter("name");
            String status = request.getParameter("status");

            // 3. 构建查询对象
            DocumentCategory category = new DocumentCategory();
            category.setName(name);
            if (status != null) {
                category.setStatus(Integer.parseInt(status));
            }

            // 4. 调用Service层的搜索方法
            PageResult pageResult = documentCategoryService.search(
                    Integer.parseInt(page),
                    Integer.parseInt(pageSize),
                    category
            );

            // 5. 返回成功结果
            return AjaxResultCQY.success("success", pageResult);

        } catch (Exception e) {
            log.error("搜索文档分类列表失败", e);
            return AjaxResultCQY.error("查询失败");
        }
    }

}
