package com.gqy.document.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.gqy.document.domain.DocumentCategory;
import com.gqy.document.domain.vo.PageResult;
import com.gqy.document.mapper.DocumentCategoryMapper;
import com.gqy.document.service.IDocumentCategoryService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 文档分类Service实现类
 *
 */
@Service
public class DocumentCategoryServiceImpl implements IDocumentCategoryService {

    private static final Logger log = LoggerFactory.getLogger(IDocumentCategoryService.class);

    @Autowired
    private DocumentCategoryMapper documentCategoryMapper;

    @Override
    public PageResult search(Integer page, Integer pageSize, DocumentCategory category) {
        try {
            // 1. 设置分页参数(PageHelper会自动添加limit语句)
            PageHelper.startPage(page, pageSize);

            // 2. 执行查询(会自动执行count查询)
            List<DocumentCategory> list = documentCategoryMapper.search(category);

            // 3. 获取分页信息
            PageInfo<DocumentCategory> pageInfo = new PageInfo<>(list);

            // 4. 封装并返回结果(注意转换为String类型)
            return new PageResult(
                    pageInfo.getPageNum(),    // 当前页码
                    pageInfo.getPageSize(),   // 每页数量
                    pageInfo.getPages(),                      // 总页数
                    pageInfo.getTotal(),                // 总记录数
                    pageInfo.getList()                       // 数据列表
            );

        } catch (Exception e) {
            log.error("搜索文档分类列表失败", e);
            return new PageResult(page,pageSize);
        }
    }
}
